' TYPE              Automation
' DESCRIPTION       Controller interface for SeaLevel 8206 USB IO Box
'
' AUTHOR            I A Heaton, Prism Sound Ltd
'
' HISTORY           1.00 First version 01/07/04 IAH
'                   1.1 Compatibility bug fix for ScriptDlg version 0.43 IAH 10 Dec 2007
'
' NOTES             Requires ScriptDlg.DLL and ActiveIOWrapper.DLL in 
'                   addition to the standard SeaIO installation      

' *** Declarations ***
Option Explicit         ' Must declare all variables before using them
Dim IOControl           ' The form object
Dim strLong             ' Long String used for constructing long messages etc.
Dim iMessageTextRed     ' Red part of message text colour
Dim iMessageTextGreen   ' Green part of message text colour
Dim iMessageTextBlue    ' Blue part of message text colour
Dim iMessageBkgndRed    ' Red part of background colour
Dim iMessageBkgndGreen  ' Green part of background colour
Dim iMessageBkgndBlue   ' Blue part of background colour
Dim iOnRed              ' For buttons that are turned on
Dim iOnGreen           
Dim iOnBlue
Dim iSenseRed           ' For inputs when sensing on
Dim iSenseGreen           
Dim iSenseBlue
Dim iOffRed             ' For buttons that are turned off
Dim iOffGreen
Dim iOffBlue
Dim i                   ' integer for counting loops

Dim strFont             ' Font name
Dim iFontSize           ' Point size of font
Dim ibuttonwidth        ' To scale the size of the buttons
Dim ibuttonheight       ' height for buttons
Dim iMode               ' True to indicate only one at a time
Dim bReadInputs         ' True to read input data
Dim strbox              ' String to appear in dialogue boxes etc
Dim strBin              ' string representing a binary number
Dim bContinue           ' boolean for controlling flow, true to keep going


'SeaLevel SeaIO variables
Dim strIOtype           'The name of the type of Sealevel device
Dim SeaIO               'the SeaIO object
Dim iIOPorts            'the total number of IO ports
Dim iInputPorts         'the total number of input ports
Dim iOutputPorts        'the total number of output ports
Dim iSampleInterval     'the sample interval in microseconds
Dim iBit                'integer number of bit to address
Dim Sense(8)            'array containing the data from each input    
Dim Relay(8)            'array containing the data from each relay 
Dim iByte               'integer value of byte used to control SeaIO device


' *** Main body of script ***

' Include access to Coloured message box
'#Include "Useful\ColourMsgBox.dss"


' Variables - Colours, fonts etc
iMessageTextRed     = 255    ' Message box text is white
iMessageTextGreen   = 255
iMessageTextBlue    = 255
iMessageBkgndRed    = 58     ' Message box background is blue
iMessageBkgndGreen  = 110
iMessageBkgndBlue   = 165
iOnRed              = 0
iOnGreen            = 255
iOnBlue             = 0
iOffRed             = 140
iOffGreen           = 140
iOffBlue            = 140
iSenseRed           = 255
iSenseGreen         = 155  
iSenseBlue          = 0

strFont             = "Arial"
iFontSize           = 7
ibuttonwidth        = 25
ibuttonheight       = 20
strbox              = "SeaIO Control"
bContinue           = true
iMode = 0
bReadInputs = false

'Setting up SeaLevel SeaIO ActiveX control via wrapper
On error resume next
Set SeaIO = CreateObject("ACTIVEIOWrapper.ActiveIoDeviceCtrl")

'Initialise the controller
On error resume next
SeaIO.Init()

'set the device number to 0
On error resume next
SeaIO.DeviceNumber = 0

'get the device ID
on error resume next
strIOtype = SeaIO.CardId
If StrIOType < 0 then
    Strlong = "Failed to find device" & vbcrlf & vbcrlf
    strlong = strlong & "No SeaLevel devices were found.  Please check that a device" & vbcrlf
    strlong = strlong & "is connected and powered and then re-start the program." & vbcrlf
    Msgbox strlong, vbexclamation, strbox
    bContinue = false
    Call IOControl.Close(1)
End If

' The following code is for a message box at startup reporting the unit
If bContinue then
    On error resume next
    iIOPorts = SeaIO.TotalportCount
    On error resume next
    iInputPorts = SeaIO.InputPortCount
    On error resume next
    iOutputPorts = SeaIO.OutputPortCount
    On error resume next
    iSampleInterval = SeaIO.SampleInterval ' in microseconds
    
    Strlong =  "Found a USB controller of type " & strIOtype & vbcrlf & vbcrlf
    strlong = strlong & "Device reports " & iIOPorts & " port(s) consisting of " & vbcrlf
    strlong = strlong &  iInputPorts & " set(s) of inputs and " 
    strlong = strlong &  iOutputPorts & " set(s) of outputs." & vbcrlf
    strlong = strlong & "Sample Interval is set to " & 1000000/iSampleInterval & "/s."
    msgbox strlong, vbinformation, "SeaLevel IO initialisation"
End If    
    
Call Create_Form



'==========================================================
Sub Create_Form
'==========================================================

    If Not bContinue then exit sub

    ' Create the form object
    Set IOControl = CreateObject("ScriptDlg.Form")
    
    With IOControl
    
        .Title = "SeaLevel " & strIOType & " Control"
        .XPos = 15
        .YPos = 115
        .SetFont strFont, iFontSize
        .InitEventHandler(IOControl)
        .RunFromdScope = false ' this is required to stop dScope shutting it down when a dScope script finishes
    
        ' Channel Buttons
        .AddStatic "RelayLabel", "Relays"
        .AddPushButton "CH0", "0", ibuttonwidth, ibuttonheight, 50
        .CH0.SetEvent_OnClick GetRef("CH0_OnClick")
        .AddPushButton "CH1", "1", ibuttonwidth, ibuttonheight
        .CH1.SetEvent_OnClick GetRef("CH1_OnClick")
        .AddPushButton "CH2", "2", ibuttonwidth, ibuttonheight
        .CH2.SetEvent_OnClick GetRef("CH2_OnClick")
        .AddPushButton "CH3", "3", ibuttonwidth, ibuttonheight
        .CH3.SetEvent_OnClick GetRef("CH3_OnClick")
        .AddPushButton "CH4", "4", ibuttonwidth, ibuttonheight
        .CH4.SetEvent_OnClick GetRef("CH4_OnClick")        
        .AddPushButton "CH5", "5", ibuttonwidth, ibuttonheight
        .CH5.SetEvent_OnClick GetRef("CH5_OnClick")
        .AddPushButton "CH6", "6", ibuttonwidth, ibuttonheight
        .CH6.SetEvent_OnClick GetRef("CH6_OnClick")
        .AddPushButton "CH7", "7", ibuttonwidth, ibuttonheight
        .CH7.SetEvent_OnClick GetRef("CH7_OnClick")
        .NewRow()
        
    End With    
    
    Call GetRelay_Status ' updates the display
    
    With IOControl
    
        ' Inputs Sense "statics" used for indicators
        .AddStatic "InputLabel", "Inputs"
        .AddStatic "Input0", "  0", ibuttonwidth + 2, ibuttonheight, 50
        .Input0.SetBackgroundColour 200, 200, 200
        .Input0.setFont strfont, ifontsize, 1
        .AddStatic "Input1", "  1", ibuttonwidth + 2, ibuttonheight
        .Input1.SetBackgroundColour 200, 200, 200
        .Input1.setFont strfont, ifontsize, 1
        .AddStatic "Input2", "  2", ibuttonwidth + 2, ibuttonheight
        .Input2.SetBackgroundColour 200, 200, 200
        .Input2.setFont strfont, ifontsize, 1
        .AddStatic "Input3", "  3", ibuttonwidth + 2, ibuttonheight
        .Input3.SetBackgroundColour 200, 200, 200
        .Input3.setFont strfont, ifontsize, 1
        .AddStatic "Input4", "  4", ibuttonwidth + 2, ibuttonheight
        .Input4.SetBackgroundColour 200, 200, 200
        .Input4.setFont strfont, ifontsize, 1
        .AddStatic "Input5", "  5", ibuttonwidth + 2, ibuttonheight
        .Input5.SetBackgroundColour 200, 200, 200
        .Input5.setFont strfont, ifontsize, 1
        .AddStatic "Input6", "  6", ibuttonwidth + 2, ibuttonheight
        .Input6.SetBackgroundColour 200, 200, 200
        .Input6.setFont strfont, ifontsize, 1
        .AddStatic "Input7", "  7", ibuttonwidth + 2, ibuttonheight
        .Input7.SetBackgroundColour 200, 200, 200
        .Input7.setFont strfont, ifontsize, 1
        .NewRow()
    
        
        'Control section
        .AddStatic "static2", "Relay mode:"  
        .AddDroplist "LinkMode", 50
        .LinkMode.AddString "None", 0
        .LinkMode.AddString "1 on", 1
        .LinkMode.AddString "1 off", 2
        .LinkMode.cursel = iMode
        .LinkMode.SetEvent_OnSelChanged GetRef ("LinkModeChanged") 
    
        ' All off/left button
        .AddPushButton "clrall", "All off", 38, ibuttonheight
        .clrall.SetEvent_OnClick GetRef("clrall_OnClick")
    
        ' All on /right button
        .AddPushButton "setall", "All On" , 38, ibuttonheight
        .Setall.SetEvent_OnClick GetRef("setall_OnClick")
    
        ' Checkbox to enable reading the inputs
        .AddCheckbox "ReadInputs", "Enable Inputs"
        .ReadInputs.checked = bReadInputs
        .ReadInputs.SetEvent_OnClick GetRef("ReadInputsChanged")
    
        ' Actually show the form...
        .Display()
    End With   
    

    Set IOControl = Nothing
    
    ' close down and set to nothing
    on error resume next
    SeaIO.Terminate()
    Set SeaIO = Nothing
    
    Automation.AUT_StopScript()

    
End Sub    

' *** Event handlers ***
'==========================================================
Sub CH0_OnClick()  ' when input 1 button is pressed
'==========================================================

    ' run mode dependent options
    Call Mode_PreSelect

    ' change state of this relay
    If Relay(0) = false then
        On Error Resume Next
        SeaIO.WriteBit 0, true, 0
    Else
        On Error Resume Next
        SeaIO.WriteBit 0, false, 0
    End If
    
    ' get status and update display
    Call GetRelay_Status

End Sub


'==========================================================
Sub CH1_OnClick()
'==========================================================

    Call Mode_PreSelect
    
    If Relay(1) = false then
        On Error Resume Next
        SeaIO.WriteBit 1, true, 0
    Else
        On Error Resume Next
        SeaIO.WriteBit 1, false, 0
    End If
    
    Call GetRelay_Status

End Sub


'==========================================================
Sub CH2_OnClick()
'==========================================================

    Call Mode_PreSelect
    
    If Relay(2) = false then
        On Error Resume Next
        SeaIO.WriteBit 2, true, 0
    Else
        On Error Resume Next
        SeaIO.WriteBit 2, false, 0
    End If
    
    Call GetRelay_Status

End Sub


'==========================================================
Sub CH3_OnClick()
'==========================================================

    Call Mode_PreSelect
    
    If Relay(3) = false then
        On Error Resume Next
        On Error Resume Next
        SeaIO.WriteBit 3, true, 0
    Else
        On Error Resume Next
        SeaIO.WriteBit 3, false, 0
    End If
    
    Call GetRelay_Status

End Sub


'==========================================================
Sub CH4_OnClick()
'==========================================================

    Call Mode_PreSelect
    
    If Relay(4) = false then
        On Error Resume Next
        SeaIO.WriteBit 4, true, 0
    Else
        On Error Resume Next
        SeaIO.WriteBit 4, false, 0
    End If
    
    Call GetRelay_Status

End Sub


'==========================================================
Sub CH5_OnClick()
'==========================================================

    Call Mode_PreSelect
    
    If Relay(5) = false then
        On Error Resume Next
        SeaIO.WriteBit 5, true, 0
    Else
        On Error Resume Next
        SeaIO.WriteBit 5, false, 0
    End If
    
    Call GetRelay_Status

End Sub


'==========================================================
Sub CH6_OnClick()
'==========================================================

    Call Mode_PreSelect
    
    If Relay(6) = false then
        On Error Resume Next
        SeaIO.WriteBit 6, true, 0
    Else
        On Error Resume Next
        SeaIO.WriteBit 6, false, 0
    End If
    
    Call GetRelay_Status

End Sub


'==========================================================
Sub CH7_OnClick()
'==========================================================

    Call Mode_PreSelect
    
    If Relay(7) = false then
        On Error Resume Next
        SeaIO.WriteBit 7, true, 0
    Else
        On Error Resume Next
        SeaIO.WriteBit 7, false, 0
    End If
    
    Call GetRelay_Status

End Sub


'==========================================================
Sub clrall_onClick()
'==========================================================

    ' action to take depends on the mode:
    Select Case iMode
        Case 0 ' button is in Clear all mode so clear all
            On Error Resume Next
            SeaIO.WriteByte 1, 0, 1
        Case 1 ' move to previous in exclusive on mode
            On Error Resume Next
            ibyte = SeaIO.ReadByte(1,1)
            ibyte = ibyte / 2
            if iByte < 1 then iByte = 128 ' change this 128 to 1 to stop it looping round
            On Error Resume Next
            SeaIO.WriteByte 1, Cint(ibyte), 1
        Case 2 ' move to previous in exclusive off mode
            On Error Resume Next
            ibyte = SeaIO.ReadByte(1,1)
            ibyte = (255 - ibyte) / 2
            if iByte < 1 then ibyte = 128 ' change this 128 to 1 to stop it looping round
            ibyte = 255 - ibyte
            On Error Resume Next
            SeaIO.WriteByte 1, Cint(ibyte), 1
    End Select             

    ' get status and update display
    Call GetRelay_Status

End Sub


'==========================================================
Sub Setall_onClick()
'==========================================================

    Select Case iMode
        Case 0 ' select all
            On Error Resume Next
            SeaIO.WriteByte 1, 255, 1
        Case 1 ' move to next in exclusive on mode
            On Error Resume Next
            ibyte = SeaIO.ReadByte(1,1)
            ibyte = ibyte * 2
            if iByte > 128 then iByte = 1 ' change this 1 to 128 to stop looping round
            On Error Resume Next
            SeaIO.WriteByte 1, Cint(ibyte), 1
        Case 2 ' move to next in exclusive off mode
            On Error Resume Next
            ibyte = SeaIO.ReadByte(1,1)
            ibyte = (255 - ibyte) * 2
            if iByte > 128 then ibyte = 1 ' see above
            ibyte = 255 - ibyte
            On Error Resume Next
            SeaIO.WriteByte 1, Cint(ibyte), 1
    End Select             

    'get status and update display
    Call GetRelay_Status

End Sub


'==========================================================
Sub GetInputs_Status
'==========================================================

    'get the device ID just to check it's still there...
    on error resume next
    strIOtype = SeaIO.CardId
    If StrIOType < 0 then
        Msgbox "Lost contact with device." & vbcrlf & "Controller will now close.", vbexclamation, strbox
        bContinue = false
        Call IOControl.Close(1)
    End If

    'Read port 0 (inputs) in absolute mode
    On Error Resume Next
    ibyte = SeaIO.ReadByte(0,1)
    
    ' if we are not interested in processing this, exit at this point
    If bReadInputs = false then
        Exit Sub
    End If    
    
    'convert the byte from decimal to a binary string
    For i = 0 To 7
        If iByte >= 2 ^ (7 - i) Then
            strBin = "1" & strBin
            iByte = iByte - 2 ^ (7 - i)
        Else
            strBin = "0" & strBin
        End If
    Next
       
    'Step through the 8 bits, setting the value of the sense array
    For i = 0 To 7
        Sense(i) = CBool(CInt(Mid(strBin, i + 1, 1)))
    Next
    
    ' process the returned integer value to find which inputs are on
    ' and set the appropriate input "static" to the correct colour
    If Sense(7) = true then 
        IOControl.Input7.setBackgroundColour iSenseRed, iSenseGreen, iSenseBlue
        IOControl.Input7.setFont strfont, ifontsize, 1
    Else 
        IOControl.Input7.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Input7.setFont strfont, ifontsize, 0
    End If
    
    If Sense(6) = true then
        IOControl.Input6.setBackgroundColour iSenseRed, iSenseGreen, iSenseBlue
        IOControl.Input6.setFont strfont, ifontsize, 1
    Else 
        IOControl.Input6.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Input6.setFont strfont, ifontsize, 0
    End If
    
    If Sense(5) = true then
        IOControl.Input5.setBackgroundColour iSenseRed, iSenseGreen, iSenseBlue
        IOControl.Input5.setFont strfont, ifontsize, 1
    Else 
        IOControl.Input5.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Input5.setFont strfont, ifontsize, 0
    End If            

    If Sense(4) = true then
        IOControl.Input4.setBackgroundColour iSenseRed, iSenseGreen, iSenseBlue
        IOControl.Input4.setFont strfont, ifontsize, 1
    Else 
        IOControl.Input4.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Input4.setFont strfont, ifontsize, 0
    End If
    
    If Sense(3) = true then
        IOControl.Input3.setBackgroundColour iSenseRed, iSenseGreen, iSenseBlue
        IOControl.Input3.setFont strfont, ifontsize, 1
    Else 
        IOControl.Input3.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Input3.setFont strfont, ifontsize, 0
    End If
    
    If Sense(2) = true then
        IOControl.Input2.setBackgroundColour iSenseRed, iSenseGreen, iSenseBlue
        IOControl.Input2.setFont strfont, ifontsize, 1
    Else 
        IOControl.Input2.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Input2.setFont strfont, ifontsize, 0
    End If            
    
    If Sense(1) = true then
        IOControl.Input1.setBackgroundColour iSenseRed, iSenseGreen, iSenseBlue
        IOControl.Input1.setFont strfont, ifontsize, 1
    Else 
        IOControl.Input1.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Input1.setFont strfont, ifontsize, 0
    End If
    
    If Sense(0) = true then
        IOControl.Input0.setBackgroundColour iSenseRed, iSenseGreen, iSenseBlue
        IOControl.Input0.setFont strfont, ifontsize, 1
    Else 
        IOControl.Input0.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Input0.setFont strfont, ifontsize, 0
    End If
    
    If iByte > 0 then 
        msgbox "Error getting status:  " & iByte, vbexclamation, strbox
    End If   
    
    
End Sub

'==========================================================
Sub GetRelay_Status
'==========================================================

    'get the device ID just to check it's still there...
    on error resume next
    strIOtype = SeaIO.CardId
    If StrIOType < 0 then
        Msgbox "Lost contact with device." & vbcrlf & "Controller will now close.", vbexclamation, strbox
        bContinue = false
        Call IOControl.Close(1)
    End If


    'Read port 1 (outputs) in absolute mode
    On error resume next
    ibyte = SeaIO.ReadByte(1,1)
    
    'convert the byte from decimal to a binary string
    For i = 0 To 7
        If iByte >= 2 ^ (7 - i) Then
            strBin = "1" & strBin
            iByte = iByte - 2 ^ (7 - i)
        Else
            strBin = "0" & strBin
        End If
    Next
       
    'Step through the 8 bits, setting the value of the sense array
    For i = 0 To 7
        Relay(i) = CBool(CInt(Mid(strBin, i + 1, 1)))
    Next
    
    ' process the returned integer value to find which inputs are on
    ' and set the appropriate input "static" to the correct colour
    If Relay(7) = true then 
        IOControl.Ch7.setBackgroundColour iOnRed, iOnGreen, iOnBlue
        IOControl.Ch7.setFont strfont, ifontsize, 1
    Else 
        IOControl.Ch7.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Ch7.setFont strfont, ifontsize, 0
    End If
    
    If Relay(6) = true then
        IOControl.Ch6.setBackgroundColour iOnRed, iOnGreen, iOnBlue
        IOControl.Ch6.setFont strfont, ifontsize, 1
    Else 
        IOControl.Ch6.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Ch6.setFont strfont, ifontsize, 0
    End If
    
    If Relay(5) = true then
        IOControl.Ch5.setBackgroundColour iOnRed, iOnGreen, iOnBlue
        IOControl.Ch5.setFont strfont, ifontsize, 1
    Else 
        IOControl.Ch5.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Ch5.setFont strfont, ifontsize, 0
    End If            

    If Relay(4) = true then
        IOControl.Ch4.setBackgroundColour iOnRed, iOnGreen, iOnBlue
        IOControl.Ch4.setFont strfont, ifontsize, 1
    Else 
        IOControl.Ch4.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Ch4.setFont strfont, ifontsize, 0
    End If
    
    If Relay(3) = true then
        IOControl.Ch3.setBackgroundColour iOnRed, iOnGreen, iOnBlue
        IOControl.Ch3.setFont strfont, ifontsize, 1
    Else 
        IOControl.Ch3.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Ch3.setFont strfont, ifontsize, 0
    End If
    
    If Relay(2) = true then
        IOControl.Ch2.setBackgroundColour iOnRed, iOnGreen, iOnBlue
        IOControl.Ch2.setFont strfont, ifontsize, 1
    Else 
        IOControl.Ch2.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Ch2.setFont strfont, ifontsize, 0
    End If            
    
    If Relay(1) = true then
        IOControl.Ch1.setBackgroundColour iOnRed, iOnGreen, iOnBlue
        IOControl.Ch1.setFont strfont, ifontsize, 1
    Else 
        IOControl.Ch1.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Ch1.setFont strfont, ifontsize, 0
    End If
    
    If Relay(0) = true then
        IOControl.Ch0.setBackgroundColour iOnRed, iOnGreen, iOnBlue
        IOControl.Ch0.setFont strfont, ifontsize, 1
    Else 
        IOControl.Ch0.setBackgroundColour iOffRed, iOffGreen, IOffBlue
        IOControl.Ch0.setFont strfont, ifontsize, 0
    End If
    
    If iByte > 0 then 
        msgbox "Error getting status:  " & iByte, vbexclamation, strbox
    End If    

    
End Sub


'==========================================================
Sub LinkModeChanged
'==========================================================

    ' if the link mode drop list changes, update the text of the buttons
    IOControl.LinkMode.GetItemData (IOControl.LinkMode.cursel), iMode
    Select Case iMode
        Case 0 
            IOControl.ClrAll.Text   = "All Off"
            IOControl.SetAll.Text   = "All On"
        Case 1, 2   
            IOControl.ClrAll.Text   = "   <    "
            IOControl.SetAll.Text   = "   >    "
        End Select    

        ' re-set the relays
        Call Mode_PreSelect
        
        ' update status and display
        Call GetRelay_Status
        
End Sub


'==========================================================
Sub Mode_PreSelect
'==========================================================
    'depending on the current mode, we need to take particular actions before
    'activating the selected relay.

    Select Case iMode
        Case 0
            'do nothing
        Case 1 'exclusive on:  clear all relays
            on error resume next
            SeaIO.WriteByte 1, 0, 1
        Case 2 'exclusive off: set all relays
            on error resume next
            SeaIO.WriteByte 1, 255, 1
    End Select    


End Sub


'==========================================================
Sub ReadInputsChanged 'runs if the "inputs on" checkbox is changed
'==========================================================

    ' retrieve the variable from the checkbox
    bReadInputs = IOControl.ReadInputs.Checked
        
    ' Keep updating the input status as long as the box is checked
    ' and the form is still active
    Do While (bReadInputs = true) and IOControl.IsActive
        Call GetInputs_Status
        WScript.Sleep 100
    Loop    

    ' if the box is not checked, grey out all the input indicators
    if bReadInputs = False and IOControl.IsActive then
        IOControl.Input7.SetBackgroundColour 200, 200, 200
        IOControl.Input7.setFont strfont, ifontsize, 1
        IOControl.Input6.SetBackgroundColour 200, 200, 200
        IOControl.Input6.setFont strfont, ifontsize, 1
        IOControl.Input5.SetBackgroundColour 200, 200, 200
        IOControl.Input5.setFont strfont, ifontsize, 1
        IOControl.Input4.SetBackgroundColour 200, 200, 200
        IOControl.Input4.setFont strfont, ifontsize, 1
        IOControl.Input3.SetBackgroundColour 200, 200, 200
        IOControl.Input3.setFont strfont, ifontsize, 1
        IOControl.Input2.SetBackgroundColour 200, 200, 200
        IOControl.Input2.setFont strfont, ifontsize, 1
        IOControl.Input1.SetBackgroundColour 200, 200, 200
        IOControl.Input1.setFont strfont, ifontsize, 1
        IOControl.Input0.SetBackgroundColour 200, 200, 200
        IOControl.Input0.setFont strfont, ifontsize, 1
        
    End If    
    
End Sub

